@@ -1,4 +1,42 @@
 
+/// Scan trait must be impl macro
+pub trait Scan<Table>{
+    fn scan(&mut self) -> crate::Result<Table>;
+}
+
+/// Scan trait must be impl macro
+pub trait Scans<Table>{
+    fn scan(&mut self) -> crate::Result<Vec<Table>>;
+}
+
+/// impl scan for table struct
+/// for example:
+/// ```rust
+/// use cdbc::{impl_scan};
+/// pub struct BizActivity {
+///     pub id: Option<String>,
+///     pub name: Option<String>,
+///     pub delete_flag: Option<i32>,
+/// }
+/// impl_scan!(SqliteRow,BizActivity{id:None,name:None,delete_flag:None});
+/// ```
+#[macro_export]
+macro_rules! impl_scan {
+    ($db_row:path,$table:path{$($field_name:ident: $field_value:expr$(,)?)+}) => {
+    impl $crate::scan::Scan<$table> for $db_row{
+      fn scan(&mut self) -> cdbc::Result<$table> {
+          $crate::row_scan!(self,$table { $($field_name:$field_value,)+})
+      }
+    }
+    impl $crate::scan::Scans<$table> for Vec<$db_row>{
+      fn scan(&mut self) -> cdbc::Result<Vec<$table>> {
+          $crate::row_scans!(self,$table { $($field_name:$field_value,)+})
+      }
+    }
+  };
+}
+
+
 /// scan CDBC Row to an Table,return cdbc::Result<Table>
 /// for example:
 ///
